<?php

/**
 * Implements hook_drush_command().
 */
function brewery_db_beer_drush_command() {
  $items = array();
  $items['import-beer'] = array(
    'description' => dt('Import beer.'),
    'options' => array(
      'start' => array(
        'description' => 'Results page to start with',
      ),
      'pages' => array(
        'description' => 'Number of pages to import',
      ),
      'since' => array(
        'description' => 'Only return items updated since this time. (Unix timestamp or string parsable by strtotime(), e.g. "-1 week"). "last" will use timestamp of last completed run.',
      ),
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
  );
  return $items;
} // end brewery_db_beer_drush_command()

/**
 * Callback for "drush import-beer" command.
 */
function drush_brewery_db_beer_import_beer() {

  $start = intval(drush_get_option('start'));
  if (!$start || $start < 1) {
    $start = 1;
  }
  $num_pages = intval(drush_get_option('pages'));
  if ($num_pages <= 0) {
    $num_pages = 0;
    $pages_text = t('all pages');
  }
  else {
    $pages_text = format_plural($num_pages, '1 page', '@count pages');
  }

  $values = array(
    '!page' => $start,
    '!pages_text' => $pages_text,
  );

  if ($since = drush_get_option('since')) {
    if ($since == 'last') {
      $since = variable_get('brewery_db_beer_last_sync', 0);
    }
    elseif (strval($since) != strval(intval($since))) {
      $since = intval(strtotime($since));
    }
  }
  if ($since < 1) {
    $since = 0;
  }
  else {
    drush_print(dt('Will retrieve updates since !since.', array('!since' => date('Y-m-d H:i:s', $since))));
  }

  if ($start == 1) {
    drush_print(dt('Preparing to import beer (!pages_text)...', $values));
  }
  else {
    drush_print(dt('Preparing to import beer (!pages_text), starting with page !page...', $values));
  }

  include_once drupal_get_path('module', 'brewery_db_beer') . '/includes/brewery_db_beer.batch.beer.inc';

  $batch = brewery_db_beer_batch_setup($start, $num_pages, $since);

  if (!$num_ops = count($batch['operations'])) {
    drush_print(dt('No beer found to import.'));
    return;
  }

  drush_print(dt('Will import !num bottles of beer.', array('!num' => $num)));

  // Get the batch process all ready!
  batch_set($batch);
  $batch =& batch_get();

  // Because we are doing this on the back-end, we set progressive to false.
  $batch['progressive'] = FALSE;

  // Start processing the batch operations.
  drush_backend_batch_process();

}
